@@ -34,7 +34,7 @@
 
 #include <folks/folks.h>
 #include <folks/folks-telepathy.h>
-#include <telepathy-glib/util.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-enum-types.h>
